/*

Copyright (C) 2016,2017 wallzero 2016,2017

This program is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software Foundation,
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this
program. If not, see <http://www.gnu.org/licenses/>.

*/

/*
  eslint-disable
  global-require,
  no-process-env,
  no-undefined,
  no-nested-ternary,
  complexity,
  import/no-commonjs,
  import/unambiguous,
  import/no-dynamic-require,
  import/max-dependencies,
  filenames/match-regex
*/

const path = require('path');
const directoryExists = require('directory-exists');
const {
  e2e, // eslint-disable-line id-match
  baseHref,
  headless,
  port,
  production,
  seleniumPort,
  seleniumStart
} = require('../config');
const {
  chromePath,
  geckoPath,
  reportsPath,
  screenshotPath,
  seleniumHost,
  seleniumPath
} = require('./vars.conf');

const defaultScreenshotPath = function (nightwatchClient, basePath, fileName) {
  return path.join(
    nightwatchClient.options.screenshotsPath || basePath || 'reports/screenshots',
    nightwatchClient.options.desiredCapabilities.platform || 'ANY',
    nightwatchClient.options.desiredCapabilities.browserName || 'UNKNOWN',
    nightwatchClient.options.desiredCapabilities.version || 'UNKNOWN',
    nightwatchClient.currentTest.name,
    fileName.replace(/ /g, '_')
  );
};

/* eslint-disable id-match */
module.exports = {
  custom_assertions_path: [
    path.join(process.cwd(), 'node_modules', 'nightwatch-vrt', 'assertions')
  ],
  custom_commands_path: [
    path.join(process.cwd(), 'node_modules', 'nightwatch-vrt', 'commands')
  ],
  output_folder: reportsPath,
  selenium: {
    cli_args: {
      'webdriver.chrome.driver': chromePath,
      'webdriver.gecko.driver': geckoPath
    },
    host: seleniumHost,
    log_path: false,
    port: seleniumPort,
    server_path: seleniumPath,
    start_process: seleniumStart
  },
  src_folders: [].concat(
    directoryExists.sync(path.join(process.cwd(), e2e)) ?
      [path.join(process.cwd(), 'src', '__e2e__')] :
      [].concat(
        directoryExists.sync(path.join(process.cwd(), 'src', '__e2e__')) ?
          [path.join(process.cwd(), 'src', '__e2e__')] :
          [],
        directoryExists.sync(path.join(process.cwd(), 'demo', '__e2e__')) ?
          [path.join(process.cwd(), 'demo', '__e2e__')] :
          []
      )
  ),
  test_settings: {
    chrome: {
      desiredCapabilities: {
        acceptSslCerts: true,
        browserName: 'chrome',
        chromeOptions: {
          args: [
            '--no-sandbox',
            '--disable-extensions',
            '--disable-gpu',
            '--window-size=1024,768'
          ].concat(
            headless ? ['--headless'] : []
          )
        },
        javascriptEnabled: true
      }
    },
    default: {
      desiredCapabilities: {
        platform: 'LINUX',
        version: 'latest'
      },
      globals: {
        prompt: !production,
        waitForConditionTimeout: 5000
      },
      launch_url: 'http://127.0.0.1:' + port + baseHref,
      screenshots: {
        enabled: true,
        on_error: false,
        on_failure: false,
        path: screenshotPath
      },
      selenium_host: seleniumHost,
      selenium_port: seleniumPort,
      silent: true,
      visual_regression_settings: {
        always_save_diff_screenshot: false,
        baseline_suffix: '.baseline',
        diff_suffix: '.diff',
        generate_screenshot_path: defaultScreenshotPath,
        latest_suffix: '.latest',
        prompt: true,
        threshold: 0.1
      }
    },
    firefox: {
      desiredCapabilities: {
        acceptSslCerts: true,
        browserName: 'firefox',
        javascriptEnabled: true,
        marionette: true,
        'moz:firefoxOptions': {
          args: [
            '-safe-mode',
            '-window-size=1024,768'
          ].concat(
            headless ? ['-headless'] : []
          )
        }
      }
    }
  }
};
/* eslint-enable id-match */

/*
  eslint-enable
  global-require,
  no-process-env,
  no-undefined,
  no-nested-ternary,
  complexity,
  import/no-commonjs,
  import/unambiguous,
  import/no-dynamic-require,
  import/max-dependencies,
  filenames/match-regex
*/
